@@ -20,16 +20,16 @@ except ImportError:
     def assert_raises_regexp(expected, regexp, callable, *a, **kw):
         try:
             callable(*a, **kw)
-        except expected, e:
+        except expected as e:
             if isinstance(regexp, basestring):
                 regexp = re.compile(regexp)
-            if not regexp.search(str(e.message)):
-                raise self.failureException('"%s" does not match "%s"' %
-                         (regexp.pattern, str(e.message)))
+            if not regexp.search(str(e)):
+                raise Exception('"%s" does not match "%s"' %
+                                (regexp.pattern, str(e)))
         else:
             if hasattr(expected,'__name__'): excName = expected.__name__
             else: excName = str(expected)
-            raise AssertionError, "%s not raised" % excName
+            raise AssertionError("%s not raised" % excName)
 
 
 try:
